@@ -78,6 +78,7 @@ RSCRIPT_EXEC     = tool('Rscript')
 SED_EXEC = tool('sed')
 FASTP_EXEC = tool('fastp')
 BAMCOVERAGE_EXEC = tool('bamCoverage')
+MEGADEPTH_EXEC = tool('megadepth')
 
 STAR_INDEX_THREADS   = config['execution']['rules']['star_index']['threads']
 HISAT2_BUILD_THREADS = config['execution']['rules']['hisat2-build']['threads']
@@ -99,10 +100,7 @@ for analysis in DE_ANALYSIS_LIST.keys():
     )
 
 ## Load sample sheet
-with open(SAMPLE_SHEET_FILE, 'r') as fp:
-  rows =  [row for row in csv.reader(fp, delimiter=',')]
-  header = rows[0]; rows = rows[1:]
-  SAMPLE_SHEET = [dict(zip(header, row)) for row in rows]
+SAMPLE_SHEET = read_sample_sheet(SAMPLE_SHEET_FILE)
 
 # Convenience function to access fields of sample sheet columns that
 # match the predicate.  The predicate may be a string.
@@ -115,6 +113,19 @@ def lookup(column, predicate, fields=[]):
 
 SAMPLES = [line['name'] for line in SAMPLE_SHEET]
 
+## Conditional output files (some steps can be executed with multiple tools, the output file list
+##  organised according to which tool the user wants to use)
+BIGWIG_OUTPUT = []
+if config['coverage']['tool'] == 'bamCoverage':
+  fw = expand(os.path.join(BIGWIG_DIR, MAPPER, 'bamCoverage', '{sample}.forward.bw'), sample = SAMPLES)
+  rv = expand(os.path.join(BIGWIG_DIR, MAPPER, 'bamCoverage', '{sample}.reverse.bw'), sample = SAMPLES) 
+  both = expand(os.path.join(BIGWIG_DIR, MAPPER, 'bamCoverage', '{sample}.bw'), sample = SAMPLES)
+  BIGWIG_OUTPUT = fw + rv + both
+elif config['coverage']['tool'] == 'megadepth': 
+  BIGWIG_OUTPUT = expand(os.path.join(BIGWIG_DIR, MAPPER, 'megadepth', '{sample}.all.bw'), sample = SAMPLES)
+else:
+  sys.exit("Error with the selected coverage computation method: Allowed options for coverage computation are 'megadepth' or 'bamCoverage'; check the settings file option under coverage->tool.")
+  
 targets = {
     # rule to print all rule descriptions
     'help': {
@@ -124,7 +135,8 @@ targets = {
     'final-report': {
         'description': "Produce a comprehensive report.  This is the default target.",
         'files':
-        [os.path.join(MULTIQC_DIR, 'multiqc_report.html'),
+        [os.path.join(OUTPUT_DIR, "input_annotation_stats.tsv"), 
+         os.path.join(MULTIQC_DIR, 'multiqc_report.html'),
          os.path.join(COUNTS_DIR, "raw_counts", "salmon", "counts_from_SALMON.transcripts.tsv"),
          os.path.join(COUNTS_DIR, "raw_counts", "salmon", "counts_from_SALMON.genes.tsv"),
          os.path.join(COUNTS_DIR, "normalized", "salmon", "TPM_counts_from_SALMON.transcripts.tsv"),
@@ -132,9 +144,7 @@ targets = {
          os.path.join(COUNTS_DIR, "raw_counts", MAPPER, "counts.tsv"),
          os.path.join(COUNTS_DIR, "normalized", MAPPER, "deseq_normalized_counts.tsv"),
          os.path.join(COUNTS_DIR, "normalized", MAPPER, "deseq_size_factors.txt")] +
-        expand(os.path.join(BIGWIG_DIR, MAPPER, '{sample}.forward.bw'), sample = SAMPLES) +
-        expand(os.path.join(BIGWIG_DIR, MAPPER, '{sample}.reverse.bw'), sample = SAMPLES) +
-        expand(os.path.join(BIGWIG_DIR, MAPPER, '{sample}.bw'), sample = SAMPLES) +
+        BIGWIG_OUTPUT +
         expand(os.path.join(OUTPUT_DIR, "report", MAPPER, '{analysis}.deseq.report.html'), analysis = DE_ANALYSIS_LIST.keys()) +
         expand(os.path.join(OUTPUT_DIR, "report", 'salmon', '{analysis}.salmon.transcripts.deseq.report.html'), analysis = DE_ANALYSIS_LIST.keys()) +
         expand(os.path.join(OUTPUT_DIR, "report",  'salmon', '{analysis}.salmon.genes.deseq.report.html'), analysis = DE_ANALYSIS_LIST.keys())
@@ -182,9 +192,7 @@ targets = {
     'genome_coverage': {
         'description': "Compute genome coverage values from BAM files - save in bigwig format",
         'files':
-          expand(os.path.join(BIGWIG_DIR, MAPPER, '{sample}.forward.bw'), sample = SAMPLES) +
-          expand(os.path.join(BIGWIG_DIR, MAPPER, '{sample}.reverse.bw'), sample = SAMPLES) +
-          expand(os.path.join(BIGWIG_DIR, MAPPER, '{sample}.bw'), sample = SAMPLES)
+          BIGWIG_OUTPUT
     },
     'salmon_index' : {
         'description': "Create SALMON index file.",
@@ -223,6 +231,16 @@ OUTPUT_FILES = list(chain.from_iterable([targets[name]['files'] for name in sele
 rule all:
   input: OUTPUT_FILES
 
+rule check_annotation_files:
+  input: 
+    dna = GENOME_FASTA,
+    cdna = CDNA_FASTA,
+    gtf = GTF_FILE
+  output: 
+    os.path.join(OUTPUT_DIR, 'input_annotation_stats.tsv')
+  log: os.path.join(LOG_DIR, 'check_annotation_files.log')
+  shell: "{RSCRIPT_EXEC} {SCRIPTS_DIR}/validate_input_annotation.R {input.gtf} {input.cdna} {input.dna} {OUTPUT_DIR} >> {log} 2>&1"
+
 rule help:
   run:
     for key in sorted(targets.keys()):
@@ -279,6 +297,8 @@ rule trim_qc_reads_pe:
     r2=os.path.join(TRIMMED_READS_DIR, "{sample}.trimmed.R2.fq.gz"),
     html=os.path.join(QC_DIR, "{sample}.pe.fastp.html"),
     json=os.path.join(QC_DIR, "{sample}.pe.fastp.json") #notice that multiqc recognizes files ending with fast.json
+  resources:
+    mem_mb = config['execution']['rules']['trim_qc_reads']['memory']
   log: os.path.join(LOG_DIR, 'trim_reads.{sample}.log')
   shell: "{FASTP_EXEC} --in1 {input[0]} --in2 {input[1]} --out1 {output.r1} --out2 {output.r2} -h {output.html} -j {output.json} >> {log} 2>&1"
 
@@ -289,30 +309,36 @@ rule trim_qc_reads_se:
     r = os.path.join(TRIMMED_READS_DIR, "{sample}.trimmed.fq.gz"),
     html=os.path.join(QC_DIR, "{sample}.se.fastp.html"),
     json=os.path.join(QC_DIR, "{sample}.se.fastp.json") #notice that multiqc recognizes files ending with fast.json
+  resources:
+    mem_mb = config['execution']['rules']['trim_qc_reads']['memory']
   log: os.path.join(LOG_DIR, 'trim_reads.{sample}.log')
   shell: "{FASTP_EXEC} --in1 {input[0]} --out1 {output.r} -h {output.html} -j {output.json} >> {log} 2>&1 "
 
 rule star_index:
-    input: GENOME_FASTA
+    input: 
+      GENOME_FASTA,
+      rules.check_annotation_files.output 
     output:
         star_index_file = os.path.join(OUTPUT_DIR, 'star_index', "SAindex")
     resources:
-      mem_mb = 32000
+        mem_mb = config['execution']['rules']['star_index']['memory']
     params:
         star_index_dir = os.path.join(OUTPUT_DIR, 'star_index')
     log: os.path.join(LOG_DIR, 'star_index.log')
-    shell: "{STAR_EXEC_INDEX} --runMode genomeGenerate --runThreadN {STAR_INDEX_THREADS} --genomeDir {params.star_index_dir} --genomeFastaFiles {input} --sjdbGTFfile {GTF_FILE} >> {log} 2>&1"
+    shell: "{STAR_EXEC_INDEX} --runMode genomeGenerate --runThreadN {STAR_INDEX_THREADS} --genomeDir {params.star_index_dir} --genomeFastaFiles {input[0]} --sjdbGTFfile {GTF_FILE} >> {log} 2>&1"
 
 rule hisat2_index:
-    input: GENOME_FASTA
+    input: 
+      GENOME_FASTA,
+      rules.check_annotation_files.output
     output:
         [os.path.join(OUTPUT_DIR, "hisat2_index", f"{GENOME_BUILD}_index.{n}.ht2l") for n in [1, 2, 3, 4, 5, 6, 7, 8]]
     resources:
-      mem_mb = 21000
+        mem_mb = config['execution']['rules']['hisat2-build']['memory']
     params:
         index_directory = os.path.join(OUTPUT_DIR, "hisat2_index"),
     log: os.path.join(LOG_DIR, 'hisat2_index.log')
-    shell: "{HISAT2_BUILD_EXEC} -f -p {HISAT2_BUILD_THREADS} --large-index {input} {params.index_directory}/{GENOME_BUILD}_index >> {log} 2>&1"
+    shell: "{HISAT2_BUILD_EXEC} -f -p {HISAT2_BUILD_THREADS} --large-index {input[0]} {params.index_directory}/{GENOME_BUILD}_index >> {log} 2>&1"
 
 def map_input(args):
   sample = args[0]
@@ -340,7 +366,7 @@ rule star_map:
   output:
     os.path.join(MAPPED_READS_DIR, 'star', '{sample}_Aligned.sortedByCoord.out.bam')
   resources:
-    mem_mb = 16000
+    mem_mb = config['execution']['rules']['star_map']['memory']
   params:
     index_dir = rules.star_index.params.star_index_dir,
     output_prefix=os.path.join(MAPPED_READS_DIR, 'star', '{sample}_')
@@ -354,7 +380,7 @@ rule hisat2_map:
   output:
     os.path.join(MAPPED_READS_DIR, 'hisat2', '{sample}_Aligned.sortedByCoord.out.bam')
   resources:
-    mem_mb = 8000
+    mem_mb = config['execution']['rules']['hisat2']['memory']
   params:
     samfile = lambda wildcards: os.path.join(MAPPED_READS_DIR, 'hisat2', "_".join([wildcards.sample, 'Aligned.out.sam'])),
     index_dir = rules.hisat2_index.params.index_directory,
@@ -373,21 +399,22 @@ rule index_bam:
   input: os.path.join(MAPPED_READS_DIR, MAPPER, '{sample}_Aligned.sortedByCoord.out.bam')
   output: os.path.join(MAPPED_READS_DIR, MAPPER, '{sample}_Aligned.sortedByCoord.out.bam.bai')
   resources:
-    mem_mb = 100
+    mem_mb = config['execution']['rules']['index_bam']['memory']
   log: os.path.join(LOG_DIR, 'samtools_index_{sample}.log')
   shell: "{SAMTOOLS_EXEC} index {input} {output} >> {log} 2>&1"
 
 rule salmon_index:
   input:
-      CDNA_FASTA
+      CDNA_FASTA,
+      rules.check_annotation_files.output
   output:
       salmon_index_file = os.path.join(OUTPUT_DIR, 'salmon_index', "pos.bin")
   resources:
-      mem_mb = 5000
+      mem_mb = config['execution']['rules']['salmon_index']['memory']
   params:
       salmon_index_dir = os.path.join(OUTPUT_DIR, 'salmon_index')
   log: os.path.join(LOG_DIR, "salmon", 'salmon_index.log')
-  shell: "{SALMON_INDEX_EXEC} -t {input} -i {params.salmon_index_dir} -p {SALMON_INDEX_THREADS} >> {log} 2>&1"
+  shell: "{SALMON_INDEX_EXEC} -t {input[0]} -i {params.salmon_index_dir} -p {SALMON_INDEX_THREADS} >> {log} 2>&1"
 
 rule salmon_quant:
   input:
@@ -400,7 +427,7 @@ rule salmon_quant:
       os.path.join(SALMON_DIR, "{sample}", "quant.sf"),
       os.path.join(SALMON_DIR, "{sample}", "quant.genes.sf")
   resources:
-      mem_mb = 6000
+      mem_mb = config['execution']['rules']['salmon_quant']['memory']
   params:
       index_dir = rules.salmon_index.params.salmon_index_dir,
       outfolder = os.path.join(SALMON_DIR, "{sample}")
@@ -419,29 +446,48 @@ rule counts_from_SALMON:
       colDataFile = rules.translate_sample_sheet_for_report.output
   output:
       os.path.join(COUNTS_DIR, "raw_counts", "salmon", "counts_from_SALMON.transcripts.tsv"),
-      os.path.join(COUNTS_DIR, "raw_counts", "salmon","counts_from_SALMON.genes.tsv"),
+      os.path.join(COUNTS_DIR, "raw_counts", "salmon", "counts_from_SALMON.genes.tsv"),
       os.path.join(COUNTS_DIR, "normalized", "salmon", "TPM_counts_from_SALMON.transcripts.tsv"),
       os.path.join(COUNTS_DIR, "normalized", "salmon", "TPM_counts_from_SALMON.genes.tsv")
   resources:
-      mem_mb = 1000
+      mem_mb = config['execution']['rules']['counts_from_salmon']['memory']
   log: os.path.join(LOG_DIR, "salmon", 'salmon_import_counts.log')
   shell: "{RSCRIPT_EXEC} {SCRIPTS_DIR}/counts_matrix_from_SALMON.R {SALMON_DIR} {COUNTS_DIR} {input.colDataFile} >> {log} 2>&1"
 
-
-rule genomeCoverage:
+# compute genome coverage using megadepth
+rule coverage_megadepth:
   input:
     bam=os.path.join(MAPPED_READS_DIR, MAPPER, '{sample}_Aligned.sortedByCoord.out.bam'),
     bai=os.path.join(MAPPED_READS_DIR, MAPPER, '{sample}_Aligned.sortedByCoord.out.bam.bai')
   output:
-    os.path.join(BIGWIG_DIR, MAPPER, '{sample}.forward.bw'),
-    os.path.join(BIGWIG_DIR, MAPPER, '{sample}.reverse.bw'),
-    os.path.join(BIGWIG_DIR, MAPPER, '{sample}.bw')
+    os.path.join(BIGWIG_DIR, MAPPER, 'megadepth', '{sample}.all.bw')
+  params:
+    out_prefix = os.path.join(BIGWIG_DIR, MAPPER, 'megadepth', '{sample}')
   log:
-    os.path.join(LOG_DIR, MAPPER, 'genomeCoverage.forward.{sample}.log'),
-    os.path.join(LOG_DIR, MAPPER, 'genomeCoverage.reverse.{sample}.log'),
-    os.path.join(LOG_DIR, MAPPER, 'genomeCoverage.{sample}.log')
+    os.path.join(LOG_DIR, MAPPER, 'coverage_megadepth.{sample}.log')
   resources:
-    mem_mb = 4000
+    mem_mb = config['execution']['rules']['coverage_megadepth']['memory'],
+    threads = config['execution']['rules']['coverage_megadepth']['threads']
+  shell:
+    """
+    {MEGADEPTH_EXEC} {input.bam} --threads {resources.threads} --bigwig --prefix {params.out_prefix} >> {log} 2>&1
+    """
+
+# compute genome coverage using bamCoverage
+rule coverage_bamCoverage:
+  input:
+    bam=os.path.join(MAPPED_READS_DIR, MAPPER, '{sample}_Aligned.sortedByCoord.out.bam'),
+    bai=os.path.join(MAPPED_READS_DIR, MAPPER, '{sample}_Aligned.sortedByCoord.out.bam.bai')
+  output:
+    os.path.join(BIGWIG_DIR, MAPPER, 'bamCoverage', '{sample}.forward.bw'),
+    os.path.join(BIGWIG_DIR, MAPPER, 'bamCoverage', '{sample}.reverse.bw'),
+    os.path.join(BIGWIG_DIR, MAPPER, 'bamCoverage', '{sample}.bw')
+  log:
+    os.path.join(LOG_DIR, MAPPER, 'coverage_bamCoverage.forward.{sample}.log'),
+    os.path.join(LOG_DIR, MAPPER, 'coverage_bamCoverage.reverse.{sample}.log'),
+    os.path.join(LOG_DIR, MAPPER, 'coverage_bamCoverage.{sample}.log')
+  resources:
+    mem_mb = config['execution']['rules']['coverage_bamCoverage']['memory']
   shell:
     """
     {BAMCOVERAGE_EXEC} -b {input.bam} -o {output[0]} --filterRNAstrand forward >> {log[0]} 2>&1
@@ -455,7 +501,7 @@ rule multiqc:
     mapping_output=expand(os.path.join(MAPPED_READS_DIR, MAPPER, '{sample}_Aligned.sortedByCoord.out.bam'), sample=SAMPLES)
   output: os.path.join(MULTIQC_DIR, 'multiqc_report.html')
   resources:
-    mem_mb = 200
+    mem_mb = config['execution']['rules']['multiqc']['memory']
   log: os.path.join(LOG_DIR, f'multiqc.{MAPPER}.log')
   shell: "{MULTIQC_EXEC} -f -o {MULTIQC_DIR} {OUTPUT_DIR} >> {log} 2>&1"
 
@@ -466,7 +512,7 @@ rule count_reads:
   output:
     os.path.join(MAPPED_READS_DIR, MAPPER, "{sample}.read_counts.csv")
   resources:
-    mem_mb = 5000
+    mem_mb = config['execution']['rules']['count_reads']['memory']
   log: os.path.join(LOG_DIR, MAPPER, "{sample}.count_reads.log")
   params:
     single_end = isSingleEnd,
@@ -483,17 +529,18 @@ rule count_reads:
 
 rule collate_read_counts:
   input:
-    expand(os.path.join(MAPPED_READS_DIR, MAPPER, "{sample}.read_counts.csv"), sample = SAMPLES)
+    colDataFile = rules.translate_sample_sheet_for_report.output,
+    count_files = expand(os.path.join(MAPPED_READS_DIR, MAPPER, "{sample}.read_counts.csv"), sample = SAMPLES)
   output:
     os.path.join(COUNTS_DIR, "raw_counts", MAPPER, "counts.tsv")
   resources:
-    mem_mb = 200
+    mem_mb = config['execution']['rules']['collate_read_counts']['memory']
   log: os.path.join(LOG_DIR, MAPPER, "collate_read_counts.log")
   params:
     mapped_dir = os.path.join(MAPPED_READS_DIR, MAPPER),
     script = os.path.join(SCRIPTS_DIR, "collate_read_counts.R")
   shell:
-    "{RSCRIPT_EXEC} {params.script} {params.mapped_dir} {output} >> {log} 2>&1"
+    "{RSCRIPT_EXEC} {params.script} {params.mapped_dir} {input.colDataFile} {output} >> {log} 2>&1"
 
 # create a normalized counts table including all samples
 # using the median-of-ratios normalization procedure of
@@ -506,7 +553,7 @@ rule norm_counts_deseq:
         size_factors = os.path.join(COUNTS_DIR, "normalized", MAPPER, "deseq_size_factors.txt"),
         norm_counts = os.path.join(COUNTS_DIR, "normalized", MAPPER, "deseq_normalized_counts.tsv")
     resources:
-      mem_mb = 1000
+      mem_mb = config['execution']['rules']['norm_counts_deseq']['memory']
     log:
         os.path.join(LOG_DIR, MAPPER, "norm_counts_deseq.log")
     params:
@@ -523,17 +570,19 @@ rule report1:
     outdir=os.path.join(OUTPUT_DIR, "report", MAPPER),
     reportR=os.path.join(SCRIPTS_DIR, "runDeseqReport.R"),
     reportRmd=os.path.join(SCRIPTS_DIR, "deseqReport.Rmd"),
+    description = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['description'].replace("'",".").replace('"','.'),
     case = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['case_sample_groups'],
     control = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['control_sample_groups'],
     covariates = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['covariates'],
+    selfContained = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['self_contained'],
     logo = LOGO
   log: os.path.join(LOG_DIR, MAPPER, "{analysis}.report.log")
   output:
     os.path.join(OUTPUT_DIR, "report", MAPPER, '{analysis}.deseq.report.html')
   resources:
-    mem_mb = 4000
+    mem_mb = config['execution']['rules']['reports']['memory']
   shell:
-    "{RSCRIPT_EXEC} {params.reportR} --logo={params.logo} --prefix='{wildcards.analysis}' --reportFile={params.reportRmd} --countDataFile={input.counts} --colDataFile={input.coldata} --gtfFile={GTF_FILE} --caseSampleGroups='{params.case}' --controlSampleGroups='{params.control}' --covariates='{params.covariates}'  --workdir={params.outdir} --organism='{ORGANISM}'  >> {log} 2>&1"
+    "{RSCRIPT_EXEC} {params.reportR} --logo={params.logo} --prefix='{wildcards.analysis}' --reportFile={params.reportRmd} --countDataFile={input.counts} --colDataFile={input.coldata} --gtfFile={GTF_FILE} --caseSampleGroups='{params.case}' --controlSampleGroups='{params.control}' --covariates='{params.covariates}'  --workdir={params.outdir} --organism='{ORGANISM}' --description='{params.description}' --selfContained='{params.selfContained}' >> {log} 2>&1"
 
 rule report2:
   input:
@@ -543,16 +592,18 @@ rule report2:
     outdir=os.path.join(OUTPUT_DIR, "report", 'salmon'),
     reportR=os.path.join(SCRIPTS_DIR, "runDeseqReport.R"),
     reportRmd=os.path.join(SCRIPTS_DIR, "deseqReport.Rmd"),
+    description = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['description'].replace("'",".").replace('"','.'),
     case = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['case_sample_groups'],
     control = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['control_sample_groups'],
     covariates = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['covariates'],
-    logo = os.path.join(config['locations']['pkgdatadir'], "images/Logo_PiGx.png") if os.getenv("PIGX_UNINSTALLED") else os.path.join(config['locations']['pkgdatadir'], "Logo_PiGx.png")
+    selfContained = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['self_contained'],
+    logo = LOGO
   log: os.path.join(LOG_DIR, "salmon", "{analysis}.report.salmon.transcripts.log")
   output:
     os.path.join(OUTPUT_DIR, "report", 'salmon', '{analysis}.salmon.transcripts.deseq.report.html')
   resources:
-    mem_mb = 4000
-  shell: "{RSCRIPT_EXEC} {params.reportR} --logo={params.logo} --prefix='{wildcards.analysis}.salmon.transcripts' --reportFile={params.reportRmd} --countDataFile={input.counts} --colDataFile={input.coldata} --gtfFile={GTF_FILE} --caseSampleGroups='{params.case}' --controlSampleGroups='{params.control}' --covariates='{params.covariates}' --workdir={params.outdir} --organism='{ORGANISM}' >> {log} 2>&1"
+    mem_mb = config['execution']['rules']['reports']['memory']
+  shell: "{RSCRIPT_EXEC} {params.reportR} --logo={params.logo} --prefix='{wildcards.analysis}.salmon.transcripts' --reportFile={params.reportRmd} --countDataFile={input.counts} --colDataFile={input.coldata} --gtfFile={GTF_FILE} --caseSampleGroups='{params.case}' --controlSampleGroups='{params.control}' --covariates='{params.covariates}' --workdir={params.outdir} --organism='{ORGANISM}' --description='{params.description}' --selfContained='{params.selfContained}' >> {log} 2>&1"
 
 rule report3:
   input:
@@ -562,13 +613,15 @@ rule report3:
     outdir=os.path.join(OUTPUT_DIR, "report", "salmon"),
     reportR=os.path.join(SCRIPTS_DIR, "runDeseqReport.R"),
     reportRmd=os.path.join(SCRIPTS_DIR, "deseqReport.Rmd"),
+    description = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['description'].replace("'",".").replace('"','.'),
     case = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['case_sample_groups'],
     control = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['control_sample_groups'],
     covariates = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['covariates'],
-    logo = os.path.join(config['locations']['pkgdatadir'], "images/Logo_PiGx.png") if os.getenv("PIGX_UNINSTALLED") else os.path.join(config['locations']['pkgdatadir'], "Logo_PiGx.png")
+    selfContained = lambda wildcards: DE_ANALYSIS_LIST[wildcards.analysis]['self_contained'],
+    logo = LOGO
   log: os.path.join(LOG_DIR, "salmon", "{analysis}.report.salmon.genes.log")
   output:
     os.path.join(OUTPUT_DIR, "report", "salmon", '{analysis}.salmon.genes.deseq.report.html')
   resources:
-    mem_mb = 4000
-  shell: "{RSCRIPT_EXEC} {params.reportR} --logo={params.logo} --prefix='{wildcards.analysis}.salmon.genes' --reportFile={params.reportRmd} --countDataFile={input.counts} --colDataFile={input.coldata} --gtfFile={GTF_FILE} --caseSampleGroups='{params.case}' --controlSampleGroups='{params.control}' --covariates='{params.covariates}' --workdir={params.outdir} --organism='{ORGANISM}' >> {log} 2>&1"
+    mem_mb = config['execution']['rules']['reports']['memory']
+  shell: "{RSCRIPT_EXEC} {params.reportR} --logo={params.logo} --prefix='{wildcards.analysis}.salmon.genes' --reportFile={params.reportRmd} --countDataFile={input.counts} --colDataFile={input.coldata} --gtfFile={GTF_FILE} --caseSampleGroups='{params.case}' --controlSampleGroups='{params.control}' --covariates='{params.covariates}' --workdir={params.outdir} --organism='{ORGANISM}' --description='{params.description}' --selfContained='{params.selfContained}' >> {log} 2>&1"
